/*
Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/

CKEDITOR.plugins.setLang( 'devtools', 'gu',
{
	devTools :
	{
		title		: 'પ્રાથમિક માહિતી',
		dialogName	: 'વિન્ડોનું નામ',
		tabName		: 'ટેબનું નામ',
		elementId	: 'પ્રાથમિક આઈડી',
		elementType	: 'પ્રાથમિક પ્રકાર'
	}
});
