/*
Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/

CKEDITOR.plugins.setLang( 'placeholder', 'et',
{
	placeholder :
	{
		title		: 'Kohahoidja omadused',
		toolbar		: 'Kohahoidja loomine',
		text		: 'Kohahoidja tekst',
		edit		: 'Kohahoidja muutmine',
		textMissing	: 'Kohahoidja peab sisaldama teksti.'
	}
});
