/*
Copyright (c) 2003-2012, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.html or http://ckeditor.com/license
*/

CKEDITOR.plugins.setLang( 'placeholder', 'no',
{
	placeholder :
	{
		title		: 'Egenskaper for plassholder',
		toolbar		: 'Opprett plassholder',
		text		: 'Tekst for plassholder',
		edit		: 'Rediger plassholder',
		textMissing	: 'Plassholderen må inneholde tekst.'
	}
});
